

# CRICBUZZ - PY



This package retrieves scores from https://www.cricbuzz.com/match-api/matches.json.

This python package uses : Requests: HTTP for Humans™

**Installing the pip package :**  
  

    pip install cricbuzz-py

  

**Importing cricbuzz-py:**  
  

    import cbpy as cb
    
[How to use cricbuzz-py ?](https://akst99.blogspot.com/2019/09/fetch-live-cricket-scores-using-python.html)


